function params = parameter()

% This function specifies the parameter of the case "standingWave".
%
% Output arguments:
% - params: struct containg parameters which specify the case.
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% parameter related to the snapshot data
params.data.generator   = @linearWaveSimulated ; % function used to generate snapshots
params.data.velocity    = 1                    ; % speed of sound
params.data.cfl         = 1                    ; % CFL number
params.data.onlyDensity = true                 ; % if true, then only density snapshots are considered whereas velocity data are ignored

% parameter related to the mode decomposition
params.mode.calculator           = @POD_main                      ; % function used for mode decomposition
params.mode.nModes               = 1                              ; % number of modes
params.mode.relErrorTol          = 1e-2                           ; % error tolerance (mode number is increased until this tolerance is met)
params.mode.shiftMatrixGenerator = @shiftMatrixGenerator_periodic ; % function  used for shifting the snapshot matrix

% parameter related to the spatial domain and discretization
params.geometry.Nxi = 200  ; % number of spatial grid points
params.geometry.L   = 2*pi ; % length of computational (1D) domain

% parameter related to the time horizon and discretization
params.time.nTimeSteps = 150 ; % number of discrete time steps

% parameter related to the plotting options
params.plot.doPlot = true ; % if true, then the function plotSpod is called in the end to produce some plots