% This script creates the plots from the paper which are related to the 
% case "standingWave".
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)

close all

% basic quantities needed for the dimensions in the following
Nxi        = size(qs, 1) ; 
nTimeSteps = size(qs, 3) ;
nVars      = 1           ;

% sampling of various constant shift velocities
sampledshiftVelocities = -1.3:0.01:1.3                             ;
nSamplingPoints        = length(sampledshiftVelocities)            ; % number of sampled shift velocities
S                      = NaN(nSamplingPoints, min(nTimeSteps,Nxi)) ; % initialization of the matrix storing the singular values for each shift velocity
for i=1:nSamplingPoints
    csi         = sampledshiftVelocities(i)                                ; % current shift velocity
    sPodSystemi = initShiftMatrix_constVelocity(params, csi)               ; % sPodSystemi is a struct containing the shift matrices
    qsShiftedi  = shiftMatrix(params, qs, 1, sPodSystemi.shiftMatrices{1}) ; % shifted snapshot matrix
    S(i,:)      = svd(reshape(qsShiftedi,Nxi*nVars,nTimeSteps))            ;
end

% plotting the singular values for various shift velocities
figure
plot(sampledshiftVelocities,S,'ko','markers',1)
xlabel('shift velocity')
ylabel('singular values')
xlim([min(sampledshiftVelocities),max(sampledshiftVelocities)])