function rhs = rhsString(q, params)

% This function returns the right-hand side of the semi-discretized linear 
% wave equation.
%
% Input arguments:
% - q: matrix of dimension Nx2, where N is the number of discrete grid
%   points; contains the current values of the density (first column) and
%   the velocity (second column).
%
% - params: struct which should at least contain the finite difference 
%   matrix and the speed fo sound.
%
%
% Output arguments:
% - rhs: matrix of same dimension as q containing the right-hand side of
%   the semi-discretized linear wave equation.
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
%

D      = params.data.D               ;
rho    = q(:,1)                      ; % current density values
u      = q(:,2)                      ; % current velocity values
rhodot = -D*u                        ; % right hand side in the equation for the time derivative of the density
udot   = -params.data.velocity*D*rho ; % right hand side in the equation for the time derivative of the velocity
rhs    = [rhodot, udot]              ;