function params = parameter()

% This function specifies the parameter of the case "twoCrossingShocks".
%
% Output arguments:
% - params: struct containg parameters which specify the case.
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% parameter related to the snapshot data
params.data.generator      = @load_extern                ; % function used to generate snapshots
params.data.name           = {'rho.mat','u.mat','p.mat'} ; % names of the files containing the snapshot data
params.data.scaleSnapshots = true                        ; % if true, then the snapshots are scaled such that the maximum value of each physical variable is 1

% parameter related to the mode decomposition
params.mode.calculator           = @sPOD_main                               ; % function used for mode decomposition
params.mode.nModes               = [4 3]                                    ; % number of modes for each velocity frame
params.mode.nErrorModesPerMode   = 2                                        ; % number of residual modes relative to "nModes" used for the sPOD algorithm 
params.mode.shiftMatrixGenerator = @shiftMatrixGenerator_constExtrapolation ; % function  used for shifting the snapshot matrix 
params.mode.nCleaningIterations  = 40000                                    ; % maximum number of cleaning iterations used in the sPOD algorithm
params.mode.lsqr.solver          = 'backslash'                              ; % option for solving the least squares problem in the sPOD algorithm (supported options: 'backslash' and 'lsqr')
params.mode.adaptiveModeAdding   = true                                     ; % if true, then the number of modes is increased in a greedy manner until the error tolerance is met
params.mode.nModesSVD            = 5                                        ; % number of modes computed in the SVDs
if(strcmp(params.mode.lsqr.solver,'lsqr')) % parameters only needed if params.mode.lsqr.solver='lsqr'
    params.mode.lsqr.tol     = 1e-3 ; % tolerance for lsqr solver
    params.mode.lsqr.maxIter = 20   ; % maximum number of iterations for lsqr solver
end
if(params.mode.adaptiveModeAdding) % parameters only needed if params.mode.adaptiveModeAdding=true
    params.mode.relErrorTol = 1e-2 ; % error tolerance (mode number is increased until this tolerance is met)
end

% parameters related to the determination of the shift values
params.SLdetection.mode                = 'trackedFronts'                                              ; % specifies the way how the shifts are determined ('trackedFronts' refers to the method where the shifts are determined via tracking)
params.SLdetection.postProcessing      = @csPostProcessingTwoShocks                                   ; % function used for post-processing the shift values
params.SLdetection.trackingFunctions   = {@(x)findLeadingShock(x,-390) ,@(x)findLeadingShock(x,-200)} ; % functions used for tracking the shifts
params.SLdetection.SourceFiles         = {'u', 'u'}                                                   ; % specifies in which snapshot matrices the shifts shall be tracked
params.SLdetection.storeIntermediateCs = true                                                         ; % if true, then the intermediate shifts before the post-processing are stored in RESULTS/intermediateCs

% parameter related to the plotting options
params.plot.doPlot = true ; % if true, then the function plotSpod is called in the end to produce some plots