% This script creates the plots from the paper which are related to the 
% case "twoCrossingShocks".
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)

close all

% snapshots of the different physical variables
rhoPlot = squeeze(qs(:,1,:))' ; % density
uPlot   = squeeze(qs(:,2,:))' ; % velocity
pPlot   = squeeze(qs(:,3,:))' ; % pressure

% quantities needed for x and t axis in the plots
Nxi        = size(qs,1)                        ; 
x          = params.geometry.dxi*(0:Nxi-1)     ;
xPlot      = x/x(end)                          ; % x axis in plot is normalized
nTimeSteps = size(qs,3)                        ;
t          = params.time.dt*(0:1:nTimeSteps-1) ;
tPlot      = t/t(end)                          ; % t axis in plot is normalized

% plotting the density snapshots
figure
pcolor(xPlot,tPlot,rhoPlot)
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Density Snapshots')

% plotting the velocity snapshots
figure
pcolor(xPlot,tPlot,uPlot)
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Velocity Snapshots')

% plotting the pressure snapshots
figure
pcolor(xPlot,tPlot,pPlot)
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Pressure Snapshots')

% loading the intermediate shifts before post-processing
S              = load('RESULTS/intermediateCs') ;
csIntermediate = S.cs                           ;

% plotting the intermediate shifts
figure
plot(tPlot,csIntermediate/x(end))
xlabel('t/t_{end}')
ylabel('x^{sh}/L')
title('Result of the Threshold Search')
legend('right border','left border')

% plotting the shifts after post-processing
figure
plot(tPlot,cs/x(end))
xlabel('t/t_{end}')
ylabel('x^{sh}/L')
title('Modified Shifts')
legend('left going shock','right going shock')

% sPOD approximations of the different physical variables
rhoTildePlot = squeeze(qsTilde(:,1,:))' ; % density
uTildePlot   = squeeze(qsTilde(:,2,:))' ; % velocity
pTildePlot   = squeeze(qsTilde(:,3,:))' ; % pressure

% plotting the error of the sPOD approximation of the density 
figure
pcolor(xPlot,tPlot,abs(rhoTildePlot-rhoPlot))
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Error in Density')

% plotting the error of the sPOD approximation of the velocity 
figure
pcolor(xPlot,tPlot,abs(uTildePlot-uPlot))
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Error in Velocity')

% plotting the error of the sPOD approximation of the pressure 
figure
pcolor(xPlot,tPlot,abs(pTildePlot-pPlot))
shading flat
xlabel('x/L')
ylabel('t/t_{end}')
colorbar
title('Error in Pressure')