function params = parameter()

% This function specifies the parameter of the case 
% "twoTransportedQuantitiesDensity".
%
% Output arguments:
% - params: struct containg parameters which specify the case.
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% parameter related to the snapshot data
params.data.generator                 = @linearWaveAnalytic ; % function used to generate snapshots
params.data.velocity                  = 1                   ; % speed of sound
params.data.relativeStartingPoint     = 0.5                 ; % center of Gaussian pulse used as initial condition (relative to params.geometry.L)
params.data.cfl                       = 1                   ; % CFL number
params.data.amplitude                 = 1                   ; % amplitude of Gaussian pulse used as initial condition
params.data.onlyDensity               = true                ; % if true, then only density snapshots are considered whereas velocity data are ignored
params.data.relativeStandardDeviation = 0.02                ; % standard deviation of Gaussian pulse used as initial condition (relative to params.geometry.L)

% parameter related to the mode decomposition
params.mode.calculator           = @sPOD_main                     ; % function used for mode decomposition
params.mode.shiftMatrixGenerator = @shiftMatrixGenerator_periodic ; % function  used for shifting the snapshot matrix 
params.mode.lsqr.solver          = 'backslash'                    ; % option for solving the least squares problem in the sPOD algorithm (supported options: 'backslash' and 'lsqr')
params.mode.saveFirstIter        = true                           ; % if true, then the modes obtained via MS&R (before the cleaning iteration) are stored in RESULTS/firstIter
params.mode.useConstVelocity     = true                           ; % if true, then a constant velocity is used for the shifts
params.mode.nModes               = [1 1]                          ; % number of modes for each velocity frame
params.mode.nErrorModesPerMode   = 2                              ; % number of residual modes relative to "nModes" used for the sPOD algorithm
params.mode.nCleaningIterations  = 40                             ; % maximum number of cleaning iterations used in the sPOD algorithm
params.mode.adaptiveModeAdding   = false                          ; % if true, then the number of modes is increased in a greedy manner until the error tolerance is met
if(strcmp(params.mode.lsqr.solver,'lsqr')) % parameters only needed if params.mode.lsqr.solver='lsqr'
    params.mode.lsqr.tol     = 1e-3 ; % tolerance for lsqr solver
    params.mode.lsqr.maxIter = 20   ; % maximum number of iterations for lsqr solver
end
if(params.mode.adaptiveModeAdding) % parameters only needed if params.mode.adaptiveModeAdding=true
    params.mode.relErrorTol = 1e-2 ; % error tolerance (mode number is increased until this tolerance is met)
end

% parameter related to the spatial domain and discretization
params.geometry.Nxi = 200  ; % number of spatial grid points
params.geometry.L   = 2*pi ; % length of computational (1D) domain

% parameter related to the time horizon and discretization
params.time.nTimeSteps = 250 ; % number of discrete time steps

% parameters related to the determination of the shift values
params.SLdetection.mode     = 'prescribedVelocity' ; % specifies the way how the shifts are determined ('prescribedVelocity' refers to shifts based on prescribed constant shift velcoities)
params.SLdetection.velocity = [1 -1]               ; % prescribed constant shift velcoities

% parameter related to the plotting options
params.plot.doPlot = true ; % if true, then the function plotSpod is called in the end to produce some plots