function params = parameter()

% This function specifies the parameter of the case "vortexPair".
%
% Output arguments:
% - params: struct containg parameters which specify the case.
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% parameter related to the snapshot data
params.data.generator            = @load_extern               ; % function used to generate snapshots
params.data.name                 = {'snapshots_vortex2D.mat'} ; % names of the files containing the snapshot data
params.data.meshCoarseningFactor = 4                          ; % positive integer to coarsen the grid in both spatial dimensions (values higher than one correspond to a reduced resolution of the snapshot matrix; the results in the paper are based on a factor of 1)
 
% parameter related to the mode decomposition
params.mode.calculator               = @sPOD_main                     ; % function used for mode decomposition
params.mode.nModes                   = [15 15]                        ; % number of modes for each velocity frame
params.mode.nErrorModesPerMode       = 1                              ; % number of residual modes relative to "nModes" used for the sPOD algorithm
params.mode.shiftMatrixGenerator     = @shiftMatrixGenerator_periodic ; % function  used for shifting the snapshot matrix 
params.mode.nCleaningIterations      = 25                             ; % maximum number of cleaning iterations used in the sPOD algorithm
params.mode.lsqr.solver              = 'lsqr'                         ; % option for solving the least squares problem in the sPOD algorithm (supported options: 'backslash' and 'lsqr')
params.mode.adaptiveModeAdding       = false                          ; % if true, then the number of modes is increased in a greedy manner until the error tolerance is met
params.mode.useAllModes              = false                          ; % if false, then the sPOD algorithm starts with one mode per frame and increases the number of modes in each cleaning iteration (bounded by nModes from above); otherwise nModes is used right from the start
params.mode.useConstVelocity         = true                           ; % if true, then a constant velocity is used for the shifts
params.mode.nModesSVD                = 30                             ; % number of modes computed in the SVDs
params.mode.negativeShiftsViaRot90   = false                          ; % if true, then the back-shift is determined by applying the function rot90 to the shift matrices; otherwise, the back-shift matrices are explicitly computed based on the negative shift
params.mode.checkConvergenceCriteria = true                           ; % if true, then the convergence criteria "singular value dominance" and "orthogonality error" (see 2D section in the paper) are computed and stored in RESULTS/convergenceCriteria
if(strcmp(params.mode.lsqr.solver,'lsqr')) % parameters only needed if params.mode.lsqr.solver='lsqr'
    params.mode.lsqr.tol     = 1e-5 ; % tolerance for lsqr solver
    params.mode.lsqr.maxIter = 20   ; % maximum number of iterations for lsqr solver
end
if(params.mode.adaptiveModeAdding) % parameters only needed if params.mode.adaptiveModeAdding=true
    params.mode.relErrorTol = 1e-2 ; % error tolerance (mode number is increased until this tolerance is met)
end

% parameters related to the determination of the shift values
params.SLdetection.mode     = 'prescribedVelocity'  ; % specifies the way how the shifts are determined ('prescribedVelocity' refers to shifts based on prescribed constant shift velcoities)
params.SLdetection.velocity = [-1.1193,2.7663; 0,0] ; % prescribed constant shift velcoities (first row: x-dimension, second row: y-dimension)

% parameter related to the plotting options
params.plot.doPlot = true ; % if true, then the function plotSpod is called in the end to produce some plots